## Version v0.2.3 (2026/04/24)

### Pull Requests Merged

#### Features added

* [PR 27](https://github.com/adybbroe/activefires-pp/pull/27) - Refactor geojson utils
* [PR 26](https://github.com/adybbroe/activefires-pp/pull/26) - Adding a unit test around the post processing main method
* [PR 25](https://github.com/adybbroe/activefires-pp/pull/25) - Add self-standing system test case

In this release 3 pull requests were closed.


## Version v0.2.2 (2025/05/19)

### Pull Requests Merged

#### Bugs fixed

* [PR 24](https://github.com/adybbroe/activefires-pp/pull/24) - Upgrade PyPi publisher

In this release 1 pull request was closed.


## Version v0.2.1 (2025/05/19)

### Pull Requests Merged

#### Features added

* [PR 23](https://github.com/adybbroe/activefires-pp/pull/23) - Update to handle new CSPP-AF 2.1 ascii file format

In this release 1 pull request was closed.


## Version v0.2.0 (2024/04/18)

### Pull Requests Merged

#### Features added

* [PR 22](https://github.com/adybbroe/activefires-pp/pull/22) - Add filter to discard spurious detections with very low FRP and high TB(I-Band 4)
* [PR 21](https://github.com/adybbroe/activefires-pp/pull/21) - Filter incoming messages on product name

In this release 2 pull requests were closed.


## Version v0.1.10 (2023/12/14)

### Pull Requests Merged

#### Bugs fixed

* [PR 20](https://github.com/adybbroe/activefires-pp/pull/20) - Fixing bug updating the detection id while running more than one day

#### Features added

* [PR 19](https://github.com/adybbroe/activefires-pp/pull/19) - Allow specify products to notify
* [PR 18](https://github.com/adybbroe/activefires-pp/pull/18) - Leave out ssh and hostname from the URI in the output message
* [PR 17](https://github.com/adybbroe/activefires-pp/pull/17) - Refactor and add sweref99 output
* [PR 15](https://github.com/adybbroe/activefires-pp/pull/15) - Add unit conversion support

In this release 5 pull requests were closed.


## Version v0.1.9 (2023/07/17)

## Version v0.1.8 (2023/07/14)


### Pull Requests Merged

#### Bugs fixed

* [PR 14](https://github.com/adybbroe/activefires-pp/pull/14) - Bugfix multipolygon treatment and adapt to latest Shapely

#### Features added

* [PR 16](https://github.com/adybbroe/activefires-pp/pull/16) - Feature add unique detection
* [PR 14](https://github.com/adybbroe/activefires-pp/pull/14) - Bugfix multipolygon treatment and adapt to latest Shapely

In this release 3 pull requests were closed.


## Version v0.1.7 (2022/10/24)


### Pull Requests Merged

#### Features added

* [PR 13](https://github.com/adybbroe/activefires-pp/pull/13) - Make thresholds configurable
* [PR 12](https://github.com/adybbroe/activefires-pp/pull/12) - More debugging and error checking

In this release 2 pull requests were closed.


## Version v0.1.6 (2022/07/15)

### Pull Requests Merged

#### Bugs fixed

* [PR 8](https://github.com/adybbroe/activefires-pp/pull/8) - Fix general local2utc time conversions

#### Features added

* [PR 8](https://github.com/adybbroe/activefires-pp/pull/8) - Fix general local2utc time conversions

In this release 2 pull requests were closed.
## Version v0.1.5 (2021/05/10)

### Pull Requests Merged

#### Bugs fixed

* [PR 7](https://github.com/adybbroe/activefires-pp/pull/7) - Fix no fires messaging

#### Features added

* [PR 7](https://github.com/adybbroe/activefires-pp/pull/7) - Fix no fires messaging

In this release 2 pull requests were closed.
